[![CircleCI](https://dl.circleci.com/status-badge/img/gh/tberlok/paicos/tree/main.svg?style=svg&circle-token=dbdb37aa907d919a167a8ef5ccf197c0d358c300)](https://dl.circleci.com/status-badge/redirect/gh/tberlok/paicos/tree/main)
[![pylint](https://github.com/tberlok/paicos/actions/workflows/pylint.yml/badge.svg)](
https://github.com/tberlok/paicos/actions/workflows/pylint.yml)
[![flake8](https://github.com/tberlok/paicos/actions/workflows/flake8.yml/badge.svg)](
https://github.com/tberlok/paicos/actions/workflows/flake8.yml)
[![Documentation Status](https://readthedocs.org/projects/paicos/badge/?version=latest)](https://paicos.readthedocs.io/en/latest/?badge=latest)


# Paicos

An object-oriented Python package for analysis of (cosmological) simulations performed
with Arepo.

<img src="images/Z24_snap130_wide_projection_notnested.jpg" width="auto">


# Documentation and asking for help

Installation instructions and tips on how to get started can be found
on [readthedocs](https://paicos.readthedocs.io/en/latest/?badge=latest).

If you have questions not answered there or if you simply can't get things working, then please feel free to create an issue or to send an email to tberlok ad nbi.ku.dk.

# Reporting issues and/or requesting features

Paicos uses GitHub Issues to track bugs and feature requests. Please search the existing issues before filing new issues to avoid duplicates.

# Contributing 
Contributions are very welcome indeed! Please see instructions [here](https://github.com/tberlok/paicos/blob/main/.github/CONTRIBUTING.md).


